"use client";
import { useRouter } from "next/navigation";
import styles from "./Login.module.css";
import { useState } from "react";
import { login } from "src/services/auth";

const LoginPage = () => {
  const [email, setEmail] = useState<string>("");
  const [senha, setPassword] = useState<string>("");
  const [loading, setLoading] = useState<boolean>(false);
  const [error, setError] = useState<string | null>(null);
  const router = useRouter();

  const handleLogin = async (e: React.FormEvent) => {
    e.preventDefault();
    setLoading(true);
    setError(null);

    try {
      console.log("Iniciando tentativa de login...");

      // Realiza a tentativa de login
      const response = await login({
        email,
        senha,
        permanecerLogado: true,
      });

      console.log("Resposta do backend:", response);

      // Extrai o token da resposta
      const { token } = response;
      if (!token) {
        throw new Error("Token não recebido do backend.");
      }

      console.log("Token recebido com sucesso:", token);

      // Salva o token no localStorage
      localStorage.setItem("token", token);

      // Redireciona para a página de cadastro
      router.push("/cadastro");
    } catch (error: unknown) {
      if (error instanceof Error) {
        console.error("Erro durante o login:", error.message);
        setError(error.message || "Erro ao realizar login.");
      } else {
        console.error("Erro desconhecido durante o login.");
        setError("Erro desconhecido ao realizar login.");
      }
    } finally {
      setLoading(false);
    }
  };

  return (
    <div className={styles.container}>
      <div className={styles.box}>
        {/* Logo Section */}
        <div className={styles.logoSection}>
          <img src="/img/logo_claro.svg" alt="Claro" className={styles.logo} />
          <div className={styles.logoFooter}>
            <img
              src="/img/logo_tcia_black.svg"
              alt="TCIA 2025"
              className={styles.logoTcia}
            />
            <div className={styles.textTcia}>
              <span>2025</span>
            </div>
          </div>
        </div>

        {/* Form Section */}
        <div className={styles.formSection}>
          <div className={styles.containerTitle}>
            <h1 className={styles.title}>Login</h1>
            <p className={styles.subtitle}>
              Entre com seu email e senha para acessar o sistema
            </p>
          </div>

          <div className={styles.containerForm}>
            <form onSubmit={handleLogin}>
              <div className={styles.containerInput}>
                {/* Input E-mail */}
                <div className={styles.inputGroup}>
                  <label htmlFor="email" className={styles.label}>
                    E-mail
                  </label>
                  <input
                    id="email"
                    type="email"
                    value={email}
                    onChange={(e) => setEmail(e.target.value)}
                    className={styles.input}
                    required
                  />
                </div>

                {/* Input Senha */}
                <div className={styles.inputGroup}>
                  <label htmlFor="password" className={styles.label}>
                    Senha
                  </label>
                  <input
                    id="password"
                    type="password"
                    value={senha}
                    onChange={(e) => setPassword(e.target.value)}
                    className={styles.input}
                    required
                  />
                </div>

                {/* Botão de Login */}
                <button className={styles.button} type="submit" disabled={loading}>
                  {loading ? "Carregando..." : "Login"}
                </button>
              </div>
            </form>

            {/* Exibição de Erro */}
            {error && <p className={styles.error}>{error}</p>}

            {/* Links Adicionais */}
            <a href="#" className={styles.link}>
              Esqueceu a senha?
            </a>
            <div className={styles.divider}>OU</div>
            <a
              type="button"
              onClick={() => router.push("/cadastro")}
              className={styles.link}
            >
              Crie sua conta
            </a>
          </div>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
